@@ -28,12 +28,13 @@ To see more about providers see :mod:`invenio_pidstore.providers`.
 from __future__ import absolute_import, print_function
 
 from collections import namedtuple
+
 from flask import current_app
 
 from .providers.recordid import RecordIdProvider
 from .providers.recordid_v2 import RecordIdProviderV2
 
-FetchedPID = namedtuple('FetchedPID', ['provider', 'pid_type', 'pid_value'])
+FetchedPID = namedtuple("FetchedPID", ["provider", "pid_type", "pid_value"])
 """A pid fetcher."""
 
 
@@ -44,11 +45,11 @@ def recid_fetcher_v2(record_uuid, data):
     :param data: The record metadata.
     :returns: A :data:`invenio_pidstore.fetchers.FetchedPID` instance.
     """
-    pid_field = current_app.config['PIDSTORE_RECID_FIELD']
+    pid_field = current_app.config["PIDSTORE_RECID_FIELD"]
     return FetchedPID(
         provider=RecordIdProviderV2,
         pid_type=RecordIdProviderV2.pid_type,
-        pid_value=str(data[pid_field])
+        pid_value=str(data[pid_field]),
     )
 
 
@@ -59,7 +60,7 @@ def recid_fetcher(record_uuid, data):
     :param data: The record metadata.
     :returns: A :data:`invenio_pidstore.fetchers.FetchedPID` instance.
     """
-    pid_field = current_app.config['PIDSTORE_RECID_FIELD']
+    pid_field = current_app.config["PIDSTORE_RECID_FIELD"]
     return FetchedPID(
         provider=RecordIdProvider,
         pid_type=RecordIdProvider.pid_type,
