@@ -13,5 +13,4 @@ from __future__ import absolute_import
 from flask import current_app
 from werkzeug.local import LocalProxy
 
-current_pidstore = LocalProxy(
-    lambda: current_app.extensions['invenio-pidstore'])
+current_pidstore = LocalProxy(lambda: current_app.extensions["invenio-pidstore"])
